##  apptioConnectionConfig
This section defines the credentials and URLs needed for connecting to Apptio systems.
  * loginUrl: login url for Apptio systems using API keys. Value is different depending on the region. EU customers, US and other customers
  * keyAccess: API key access generated on Apptio for the environment to be used
  * keySecret: API key secret generated on Apptio for the environment to be used
  * domain: domain name containing the tables to be used
  * environmentName: environment name containing the tables to be used
  * ulsUrl: Apptio Uploader Service url, used for writing to Apptio tables. Note that it is a different url depending on the zone your Apptio environment is located. EU, North America, APAC
